@@ -4,6 +4,7 @@ from .filterable import Filterable
 from .hashable import Hashable
 from .identifiable import Identifiable
 from .labelable import Labelable
+from .metadata import Metadata
 from .serialisable import Serialisable
 from .taggable import Taggable
 
@@ -14,6 +15,7 @@ __all__ = (
     "Hashable",
     "Identifiable",
     "Labelable",
+    "Metadata",
     "MixinBase",
     "Serialisable",
     "Taggable",
